@@ -9,6 +9,7 @@ def test2():
     t = pd.DataFrame(data=[1,2,3])
     display(t)
 
+##########################################################csv변환
 def t_csv(x,y,z):
     if y==40:
         x.to_csv('land40_{}.csv'.format(z),encoding='cp949')
@@ -17,6 +18,7 @@ def t_csv(x,y,z):
     if y==70:
         x.to_csv('land70_{}.csv'.format(z),encoding='cp949')
 
+############################################################거리계산
 def make_distance(x,y,name):
     df = pd.DataFrame()
     
@@ -33,4 +35,17 @@ def make_distance(x,y,name):
     df = df.groupby(['아파트']).agg(['count', 'mean']).reset_index()
     df.columns=['주소', name+' 개수', name+' 평균거리']
     apt_df = pd.merge(x, df, left_on = '주소', right_on = '주소', how = 'left')
-    return apt_df
\ No newline at end of file
+    return apt_df
+
+###########################################################맵 마커 
+def cir_marker(x,y,name):
+    df2 = pd.DataFrame()
+    for i in range(len(x)):
+        for j in range(len(y)):
+            distance = haversine(x.loc[:,['위도','경도']].values[i],
+                                 y.loc[:,['위도','경도']].values[j],
+                                 unit = 'km')
+            if distance <= 1:
+                data ={str(name) : y['위도'].values[j],str(name): y['경도'].values[j]}
+                df2 = df2.append(data,ignore_index=True)
+    return df2
\ No newline at end of file
